@@ -51,6 +51,8 @@ app_path="./"
 passed_time=0
 last_beep=0
 #graphBlocks=0
+OfflineMode="True"
+#OldOfflineMode="False" #restore original state after recording
 
 #arrays, indexes, lenghts
 arrDataLen=4680 #(1 value/10sec for 13h), 6*13*60
