@@ -7,8 +7,6 @@
 # Licence:         GPL
 ###########################################################################
 
-#TODO:
-#show folder somewhere
 
 import sys
 import random
@@ -34,6 +32,7 @@ from myFunctions2 import * #Own functions
 from Ui_StartWindow import *
 from Ui_RecordWindow import *
 from Ui_ViewWindow import *
+from Ui_ConfigWindow import *
 
 
 
@@ -43,7 +42,7 @@ from Ui_ViewWindow import *
 # Main function
 ###########################################################################
 def main():
-    global app,  StartWindow,  RecordWindow,  ViewWindow 
+    global app,  StartWindow,  RecordWindow,  ViewWindow ,  ConfigWindow
     global config
     global RecordWindowGraph
    
@@ -65,7 +64,7 @@ def main():
         data.logfolder=data.devlogfolder
     else: data.logfolder=data.defaultlogfolder
 
-    app = QtGui.QApplication(sys.argv)
+    app = QApplication(sys.argv)
     
     config=LoadConfig()
     
@@ -74,13 +73,19 @@ def main():
     else: data.app_path=data.app_path+"/"
     
     StartWindow = frmStartWindow()    
-    RecordWindow = frmRecordWindow()
-    ViewWindow = frmViewWindow()
-    
-    StartWindow.show()      
-
+    StartWindow.show()    
     StartWindow.UpdateScreenStart()
-    StartWindow.show()
+    
+    # Create subwindows
+    RecordWindow = frmRecordWindow(StartWindow)
+    ViewWindow = frmViewWindow(StartWindow)
+    ConfigWindow = frmConfigWindow(StartWindow)
+    
+    # Hide SubWindows at first
+    RecordWindow.hide()
+    ViewWindow.hide()
+    ConfigWindow.hide()
+    
     
     #get user name for in log files
     if(data.user==""):
@@ -138,6 +143,9 @@ def StartMeasurement():
     
     if(data.Mode==0):
         interval=data.sampling #normal
+        if(data.OfflineMode=="True"): #change to offline mode
+            cmd="dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:\"offline\""
+            os.popen(cmd)
     else:  
         interval=10 #Fast mode for testing
     
@@ -171,7 +179,13 @@ def StopMeasurement():
     app.timer_GetData.stop()
     data.run=0
     StopLogfile()       
-    data.test=0 # reset test mode if was active
+    
+    if(data.Mode==0): #normal mode
+        if(data.OfflineMode=="True" and data.demo!=1): #change to offline mode
+            cmd="dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:\"normal\""
+            os.popen(cmd)
+    else: #test mode
+        data.test=0 # reset test mode if was active
 
 
 
@@ -223,18 +237,29 @@ def MoveTrigger(direction):
 
 
 
+
+
+
+
+
+
+
+
 ###########################################################################
 #  Class for Main Window
 ###########################################################################
-class frmStartWindow(QtGui.QWidget):
-    def __init__(self, parent=None):
-        QtGui.QWidget.__init__(self, parent)
+class frmStartWindow(QMainWindow):
+    def __init__(self):
+        QMainWindow.__init__(self)
+        # This attribute makes the whole Stacked Window thing work
+        self.setAttribute(Qt.WA_Maemo5StackedWindow)
         self.ui = Ui_StartWindow()
         self.ui.setupUi(self)
 
         QtCore.QObject.connect(self.ui.bCollecting, QtCore.SIGNAL("clicked()"), self.StartMeasurementNormal)
         QtCore.QObject.connect(self.ui.bQuick, QtCore.SIGNAL("clicked()"), self.StartMeasurementQuick)
         QtCore.QObject.connect(self.ui.bLog, QtCore.SIGNAL("clicked()"), self.ShowViewWindow)
+        QtCore.QObject.connect(self.ui.bConfig, QtCore.SIGNAL("clicked()"), self.ShowConfigWindow)
         
         file = open(data.app_path+"Info.htm", 'r')
         txt=""
@@ -247,6 +272,7 @@ class frmStartWindow(QtGui.QWidget):
             self.ui.bQuick.setIcon(QIcon(data.app_path+"krec.png"))
             self.ui.bCollecting.setIcon(QIcon(data.app_path+"krec.png"))
             self.ui.bLog.setIcon(QIcon(data.app_path+"zoom.png"))
+            self.ui.bConfig.setIcon(QIcon(data.app_path+"configure.png"))
 
 
 
@@ -255,7 +281,7 @@ class frmStartWindow(QtGui.QWidget):
     ###########################################################################
     def StartMeasurementNormal(self):
         data.Mode=0 #run in normal mode
-        data.test=0 #show axis lables
+        data.test=0 #show axis lables        
         self.StartMeasurement()
         
         
@@ -272,8 +298,8 @@ class frmStartWindow(QtGui.QWidget):
     def StartMeasurement(self):
         global RecordWindowGraph
         RecordWindow.show()
-        StartWindow.hide()
-        RecordWindowGraph = RecordWindowCanvas()
+#        StartWindow.hide()
+        RecordWindowGraph = RecordWindowCanvas(RecordWindow)
         StartMeasurement()
         RecordWindow.UpdateScreenStart()
         RecordWindowGraph.show()
@@ -308,13 +334,21 @@ class frmStartWindow(QtGui.QWidget):
         
 #        print data.logfilename
         
-        ViewWindowGraph = ViewWindowCanvas()
+        ViewWindowGraph = ViewWindowCanvas(self)
         ViewWindow.ShowLogFile()
         
         ViewWindow.show()
-        StartWindow.hide()
+#        StartWindow.hide()
         
         
+        
+    def ShowConfigWindow(self):
+        ConfigWindow.UpdateScreen()
+        ConfigWindow.show()
+#        StartWindow.hide()
+
+
+
 
     def UpdateScreenStart(self):
         try:   
@@ -325,7 +359,7 @@ class frmStartWindow(QtGui.QWidget):
             data.build = file.readline()
         except:
             print "Version file not found"
-        self.ui.lblVersion.setText(data.version+"."+data.build)
+        self.ui.lblVersion.setText("Version: "+data.version+"-"+data.build)
         self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"SleepAnalyser.png"))
 
     def closeEvent(self, event):
@@ -346,12 +380,19 @@ class frmStartWindow(QtGui.QWidget):
 
 
 
+
+
 ###########################################################################
 #  Class for Collecting Window
 ###########################################################################
-class frmRecordWindow(QtGui.QWidget):
+class frmRecordWindow(QMainWindow):
     def __init__(self, parent=None):
-        QtGui.QWidget.__init__(self, parent)
+#        QMainWindow.__init__(self, parent)
+        # Notice that you must give a parent window as parameter to the constuctor
+        QMainWindow.__init__(self, parent)
+        # Also set the Stacked Window parameter for every subwindow in the stack
+        self.setAttribute(Qt.WA_Maemo5StackedWindow)
+        
         self.ui = Ui_RecordWindow()
         self.ui.setupUi(self)
         
@@ -484,12 +525,28 @@ class frmRecordWindow(QtGui.QWidget):
 
 
 
+
+
+
+
+
+
+
+
+
+
 ###########################################################################
 # Class for Log Window
 ###########################################################################
-class frmViewWindow(QtGui.QWidget):
+class frmViewWindow(QMainWindow):
     def __init__(self, parent=None):
-        QtGui.QWidget.__init__(self, parent)
+#        QMainWindow.__init__(self, parent)
+        # Notice that you must give a parent window as parameter to the constuctor
+        QMainWindow.__init__(self, parent)
+        # Also set the Stacked Window parameter for every subwindow in the stack
+        self.setAttribute(Qt.WA_Maemo5StackedWindow)
+        
+        
         self.ui = Ui_ViewWindow()
         self.ui.setupUi(self)
         
@@ -524,12 +581,23 @@ class frmViewWindow(QtGui.QWidget):
 
 
     def UpdateScreen(self):
-        self.ui.lblLogfile.setText(data.logfilename)
-        self.ui.lblStarttime.setText(str(data.arrData[0][0]))
-        self.ui.lblStoptime.setText(str(data.arrData[0][data.arrDataIndex-1]))
+        shortfolder=string.replace(data.logfolder, "/home/user/MyDocs", "~")
+        self.ui.lblLogfile.setText(data.logfilename+" (in "+shortfolder+")")
+        self.ui.lblStarttime.setText("Start: "+str(data.arrData[0][0]))
+        self.ui.lblStoptime.setText("End: "+str(data.arrData[0][data.arrDataIndex-1]))
 #        self.ui.lblTrigger.setText(str(data.trigger))
 #        self.ui.lblYscale.setText(str(data.Yscale))
         self.ui.lblNote.setText(str(data.Note))
+        
+        try:
+            t0=time.strptime("2000-1-1 "+str(data.arrData[0][0]), "%Y-%m-%d %H:%M:%S")
+            t1=time.strptime("2000-1-1 "+str(data.arrData[0][data.arrDataIndex-1]), "%Y-%m-%d %H:%M:%S")
+            t0=time.mktime(t0)
+            t1=time.mktime(t1)
+            t=strftime("%H:%M:%S", time.gmtime(t1-t0))
+        except:
+            t="??"
+        self.ui.lblDuration.setText("Duration: "+str(t))
 
         if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
         else: self.ui.bZoomIn.setEnabled(True)
@@ -559,7 +627,7 @@ class frmViewWindow(QtGui.QWidget):
         ProcessData()
         data.Xscale=1 #default zoom level
         data.ChangesInGraph=1 #Make sure it only gets refreshed once
-        ViewWindowGraph = ViewWindowCanvas()
+        ViewWindowGraph = ViewWindowCanvas(self)
         ViewWindowGraph.show()
         self.UpdateScreen()
         
@@ -690,43 +758,81 @@ class frmViewWindow(QtGui.QWidget):
 
 
 
+###########################################################################
+# Class for Configuration Window
+###########################################################################
+class frmConfigWindow(QMainWindow):
+    def __init__(self, parent):
+        # Notice that you must give a parent window as parameter to the constuctor
+        QMainWindow.__init__(self, parent)
+        # Also set the Stacked Window parameter for every subwindow in the stack
+        self.setAttribute(Qt.WA_Maemo5StackedWindow)
+        
+        self.ui = Ui_ConfigWindow()
+        self.ui.setupUi(self)
+        self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"SleepAnalyser.png"))
+        
+      
+        
+        
+
+    def UpdateScreen(self):
+        if(data.OfflineMode=="True"): self.ui.cOfflineMode.setChecked(True)
+        else: self.ui.cOfflineMode.setChecked(False)        
+        self.ui.txtUserName.setPlainText(str(data.user))
+
+
+    def closeEvent(self, event):        
+        if(self.ui.cOfflineMode.isChecked()==True):          
+                data.OfflineMode="True"
+        else: 
+            data.OfflineMode="False"
+        config.set('main', 'OfflineMode', str(data.OfflineMode))      
+        
+        data.user=str(self.ui.txtUserName.toPlainText())
+        config.set('main', 'user', str(data.user))      
+        
+        ConfigWindow.close()
+        StartWindow.show()
+
+
+
+
+
+
+
+
+
+
 
 
 ###########################################################################
 # Class for drawing the RecordWindowGraph
 ###########################################################################
 class RecordWindowCanvas(QtGui.QWidget):
-    def __init__(self, parent=None):
-        QtGui.QWidget.__init__(self, RecordWindow)    
-        self.setGeometry(9, 180, 782, data.Ysize+30)
+    def __init__(self, parent):
+        QMainWindow.__init__(self, parent)    
+        self.setGeometry(9, 180, 782, data.Ysize+55)
     
     def paintEvent(self, event):
         showGraph(self,  QtGui)
 
 
 
-
-
-    
     
 ###########################################################################
 # Class for drawing the ViewWindowGraph
 ###########################################################################
 class ViewWindowCanvas(QtGui.QWidget):
-    def __init__(self, parent=None):
-        QtGui.QWidget.__init__(self, ViewWindow)    
-        self.setGeometry(9, 100, 782, data.Ysize+30)
+    def __init__(self, parent):
+        QMainWindow.__init__(self, parent)    
+        self.setGeometry(9, 100, 782, data.Ysize+55)
     
     def paintEvent(self, event):
         showGraph(self,  QtGui)
     
     
     
-
-    
-    
-    
-
 ###########################################################################
 # Now we can start it.
 main()
