@@ -197,6 +197,7 @@ def LoadConfig():
         data.user = config.get('main', 'user')
         data.lastlogfile = config.get('main', 'lastlogfile')
         print "Configuration loaded ("+data.ConfigFile+")"
+        data.OfflineMode = config.get('main', 'OfflineMode')
 #    else:
     except: #use default config
         print data.configfolder+data.ConfigFile + " not existing, using default parameters..."
@@ -213,7 +214,8 @@ def LoadConfig():
         config.set('main', 'Xscale', str(data.Xscale))     
         config.set('main', 'Yscale', str(data.Yscale))      
         config.set('main', 'user', str(data.user))      
-        config.set('main', 'lastlogfile', str(data.lastlogfile))      
+        config.set('main', 'lastlogfile', str(data.lastlogfile))    
+        config.set('main', 'OfflineMode', str(data.OfflineMode))      
 
     
     #print usefull data
