@@ -35,7 +35,7 @@ def ReadAccSensor():
         coords[0]=int(random.uniform(-50,50))
         coords[1]=int(random.uniform(-50,50))
 
-    print coords[0],  coords[1]
+#    print coords[0],  coords[1]
     return coords
 
 
@@ -67,7 +67,7 @@ def GetSensorData():
         data.arrDataTemp[0]=0
         data.arrDataTemp[1]=0
 
-        print "smoothened:",  data.arrData[1][data.arrDataIndex],  data.arrData[2][data.arrDataIndex]
+#        print "smoothened:",  data.arrData[1][data.arrDataIndex],  data.arrData[2][data.arrDataIndex]
         return 1 #added new values to arrData     (interval: sampling*sample_smoothing*value_smoothing)
     else: return 0 #no new data added
 
@@ -178,13 +178,17 @@ def showGraph(self,  QtGui):
         
         #main lines + text
         if(data.test==0):
-            for i in range(0, 781+decade,  decade):
+            print decade,  offset
+            for i in range(-1*decade, 781+decade,  decade):
                 paint.drawLine(i+offset, data.Ysize, i+offset, data.Ysize+10)  
                 for k in range(1, 6):
                     x=i+offset+k*decade/6-decade
                     paint.drawLine(x, data.Ysize, x, data.Ysize+5)  
                 h=(h0+int(i/decade)+1) % 24
                 paint.drawText(i+offset-20, data.Ysize+30, str(h)+":00") 
+                if(data.Xscale==0):
+                    paint.drawText(i+offset-20+decade/3, data.Ysize+30, str(h)+":20") 
+                    paint.drawText(i+offset-20+2*decade/3, data.Ysize+30, str(h)+":40") 
         else: #test mode, do not show X scale as it is wrong
             paint.drawText(200, data.Ysize+20, "Test Mode")
 
@@ -194,10 +198,28 @@ def showGraph(self,  QtGui):
         paint.drawLine(1, y-15, 781, y-15)  
         paint.drawText(760, y-17, str(data.trigger))
         
-        #show y scale
+        #show Y scale
         paint.drawText(5, 15, str(data.Yscale))
 
 
+        #scroll bar border
+        GraphEnd=data.arrDataIndex/Xscale
+        if(GraphEnd<>0): SelectionStart=(GraphStart*100/GraphEnd)*779/100
+        else: SelectionStart=0
+        if(SelectionStart>0): #show scroll bar
+            paint.setPen(QtGui.QColor("gray"))
+            paint.drawRect(0,data.Ysize+37,781,7)
+            #Scroll bar
+    #        0%=1
+    #    100%=780
+    #        startpercent=GraphStart/data.arrDataIndex*100
+    #        print startpercent,  data.arrDataIndex
+            print GraphStart,  GraphEnd,  GraphStart*100/GraphEnd, "%"
+#            print x
+            paint.setPen(QtGui.QColor("white"))
+            paint.setBrush(QtGui.QColor("white"))
+            paint.drawRect(SelectionStart,data.Ysize+38,780,5)
+
 
         #draw graph
         lastmove=0
@@ -207,9 +229,9 @@ def showGraph(self,  QtGui):
         peak=0   
         for i in range(0,  end,  Xscale):
             k=i+GraphStart
-            
-            
-            
+
+
+
             #when Xscale is small, we have to merge several records into 1 pixel.
             #To not miss any movement, we use the biggest movement of the merged records:
             peak=0            
@@ -218,14 +240,14 @@ def showGraph(self,  QtGui):
 #                Show_passed_time("L 1")
                 p=abs(data.arrData[3][k])+abs(data.arrData[4][k])
                 if(p>peak): peak=p
-           
-            
-            
-            
+   
+    
+    
+    
 #            if(1): #one or more movement for this pixel
 #                peak=abs(data.arrData[3][k])+abs(data.arrData[4][k])
             Y=peak*data.Yscale
-            if(Y>=data.Ysize+17): 
+            if(Y>=data.Ysize-17): 
                 Y=data.Ysize-17
 #                print "too big:",  Y,  peak*data.Yscale
             #Draw movement line
@@ -238,9 +260,9 @@ def showGraph(self,  QtGui):
 #            print i,  end,  Xscale
             if(peak>data.trigger or i>=end-Xscale):
 #            if(peak>data.trigger):
-                
-                        
-                        
+
+
+
 #                Show_passed_time("L 2")
 ##                    1=10 sec
 #                    if((i-lastmove)>30*Xscale): color="#009100" #green
@@ -253,16 +275,19 @@ def showGraph(self,  QtGui):
 
                 x0=lastmove/Xscale+1
                 x1=i/Xscale-1
-                if(x0<x1):
+                len=x1-x0
+#                if(len==0): len=1
+                if(x0<=x1):
                     t=(x1-x0)*Xscale/6          
 #                        print x0,  "<=>",  x1,  t,  Xscale
                     if(t>30): color="#009100" #green
                     elif(t>15): color="#005000" #dark green
+                    elif(t>7): color="#97320e" #orange
                     else: color="#6D0000" #dark red       
 #                    print "draw rect with color",  color                  
                     paint.setBrush(QtGui.QColor(color))
                     paint.setPen(QtGui.QColor(color))
-                    paint.drawRect(x0+1, data.Ysize-11, x1-x0+1, 10)                     
+                    paint.drawRect(x0+1, data.Ysize-11, len, 10)                     
                     paint.setPen(QtGui.QColor("yellow"))
 #                        print "=     Draw field",  x0,  x1,  data.Ysize,  color
                 lastmove=i
